@@ -6,4 +6,4 @@ const getBuffer = require("./index").getBuffer;
 const formatter = createFromBuffer(getBuffer());
 const result = formatter.formatText("file.sql", "SELECT  *  FROM dbo.Test");
 
-assert.strictEqual(result, "SELECT * FROM dbo.Test\n");
+assert.strictEqual(result, "SELECT\n    *\nFROM\n    dbo.Test\n");
